# Vidhash
[Vidhash](https://pypi.org/project/vidhash/) is a perceptual video hashing and checking library, to detect similar videos, or videos containing similar scenes.


## Todo
- Code
  - Ability to ignore blank frames
  - Ensure hash settings are the same when checking similarity
  - Wrapper for imagehash.ImageHash
  - Datastore
    - (For looking up matching videos from a collection)
- Documentation
- Tests
